@@ -51,8 +51,15 @@ class AStar(Graph):
                 reconst_path.append(start)
  
                 reconst_path.reverse()
- 
-                print('Path found: {}'.format(reconst_path))
+                print("Path")
+                for i in range(len(reconst_path) - 1):
+                    print(f"{reconst_path[i]} -> ",end="")
+                print(reconst_path[-1])
+                print("Cost")
+                for i in range(len(reconst_path) - 1):
+                    print(f"{poo[reconst_path[i]]} -> ",end="")
+                print(poo[reconst_path[-1]])
+                # print('Path found: {} and the total cost is {}'.format(reconst_path,poo[stop]))
                 return reconst_path
  
             # for all the neighbors of the current node do
@@ -82,4 +89,17 @@ class AStar(Graph):
             closed_lst.add(n)
  
         print('Path does not exist!')
-        return None
\ No newline at end of file
+        return None
+
+adjacency_list = {
+    'S': [('A', 1), ('G', 10)],
+    'A': [('B', 2), ('C', 1)],
+    'B': [('D', 5)],
+    'C': [('D', 3), ('G', 4)],
+    'D': [('C', 3), ('G', 2)]
+}
+
+heuristics = {'S':5, 'A':3, 'B':4, 'C':2, 'D':6, 'G':0}
+
+graph = AStar(adjacency_list, heuristics)
+graph.apply_a_star(start='S',stop='G')
\ No newline at end of file
